@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class TestExportFile : public QObject
     Q_OBJECT
 public:
     explicit TestExportFile(QObject *parent = nullptr);
-    ~TestExportFile();
+    ~TestExportFile() override;
 
     Q_REQUIRED_RESULT QByteArray pathConfig() const;
     void setPathConfig(const QByteArray &pathConfig);
