@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class TestImportFile : public QObject
     Q_OBJECT
 public:
     explicit TestImportFile(const QString &archivePath, QObject *parent = nullptr);
-    ~TestImportFile();
+    ~TestImportFile() override;
 
     void start();
     Q_REQUIRED_RESULT AbstractImportExportJob *abstractImportExportJob() const;
