@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -32,16 +32,16 @@ ShowArchiveStructureDialog::ShowArchiveStructureDialog(const QString &filename,
 {
     setWindowTitle(i18nc("@title:window", "Show Archive Content on file \"%1\"", filename));
     setModal(true);
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     mTreeWidget = new QTreeWidget(this);
     mTreeWidget->header()->hide();
     mTreeWidget->setAlternatingRowColors(true);
 
-    auto *searchLine = new KTreeWidgetSearchLine(this, mTreeWidget);
+    auto searchLine = new KTreeWidgetSearchLine(this, mTreeWidget);
     searchLine->setPlaceholderText(i18n("Search..."));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
-    auto *user1Button = new QPushButton(this);
+    auto user1Button = new QPushButton(this);
     user1Button->setText(i18n("Save As Text..."));
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
 
@@ -90,11 +90,12 @@ void ShowArchiveStructureDialog::slotOpenFile()
             const KArchiveDirectory *topDirectory = mZip->directory();
             const KArchiveEntry *currentEntry = topDirectory->entry(fullPath);
             if (currentEntry && currentEntry->isFile()) {
-                const auto *currentFile = static_cast<const KArchiveFile *>(currentEntry);
+              const auto currentFile =
+                  static_cast<const KArchiveFile *>(currentEntry);
 
-                if (!mTempDir) {
-                    mTempDir = new QTemporaryDir;
-                }
+              if (!mTempDir) {
+                mTempDir = new QTemporaryDir;
+              }
                 const QString fileName = mTempDir->path() + QLatin1Char('/') + currentItem->text(0);
                 QFile f(fileName);
                 if (!f.open(QIODevice::WriteOnly)) {
@@ -124,22 +125,30 @@ void ShowArchiveStructureDialog::slotExtractFile()
             const KArchiveDirectory *topDirectory = mZip->directory();
             const KArchiveEntry *currentEntry = topDirectory->entry(fullPath);
             if (currentEntry && currentEntry->isFile()) {
-                const auto *currentFile = static_cast<const KArchiveFile *>(currentEntry);
-                const QString dir = QFileDialog::getExistingDirectory(this, i18n("Select Directory"),
-                                                                      QDir::homePath(),
-                                                                      QFileDialog::ShowDirsOnly
-                                                                      | QFileDialog::DontResolveSymlinks);
-                if (!dir.isEmpty()) {
-                    if (QFile(dir + QLatin1Char('/') + currentFile->name()).exists()) {
-                        if (KMessageBox::questionYesNo(this, i18n("Do you want to override %1?", currentFile->name()), i18n("File Already Exist")) == KMessageBox::No) {
-                            return;
-                        }
-                    }
-                    if (!currentFile->copyTo(dir)) {
-                        KMessageBox::error(this, i18n("Impossible to copy %1 in %2.", currentFile->name(), dir));
-                        qCWarning(PIMDATAEXPORTERGUI_LOG) << "Impossible to extract file: " << currentItem->text(0) << " to " << dir;
-                    }
+              const auto currentFile =
+                  static_cast<const KArchiveFile *>(currentEntry);
+              const QString dir = QFileDialog::getExistingDirectory(
+                  this, i18n("Select Directory"), QDir::homePath(),
+                  QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
+              if (!dir.isEmpty()) {
+                if (QFile(dir + QLatin1Char('/') + currentFile->name())
+                        .exists()) {
+                  if (KMessageBox::questionYesNo(
+                          this,
+                          i18n("Do you want to override %1?",
+                               currentFile->name()),
+                          i18n("File Already Exist")) == KMessageBox::No) {
+                    return;
+                  }
                 }
+                if (!currentFile->copyTo(dir)) {
+                  KMessageBox::error(this, i18n("Impossible to copy %1 in %2.",
+                                                currentFile->name(), dir));
+                  qCWarning(PIMDATAEXPORTERGUI_LOG)
+                      << "Impossible to extract file: " << currentItem->text(0)
+                      << " to " << dir;
+                }
+              }
             }
         }
     }
@@ -147,7 +156,7 @@ void ShowArchiveStructureDialog::slotExtractFile()
 
 void ShowArchiveStructureDialog::slotItemClicked(QTreeWidgetItem *item, int column)
 {
-    Q_UNUSED(column);
+    Q_UNUSED(column)
     if (item) {
         const QString fullPath = item->data(0, FullPath).toString();
         const bool enableButton = !fullPath.isEmpty();
@@ -208,49 +217,56 @@ bool ShowArchiveStructureDialog::searchArchiveElement(const QString &path, const
 
 void ShowArchiveStructureDialog::addSubItems(const QString &topLevelPath, QTreeWidgetItem *parent, const KArchiveEntry *entry, int indent, const QString &fullpath)
 {
-    const auto *dir = static_cast<const KArchiveDirectory *>(entry);
-    ++indent;
-    const QString space = QString(indent * 2, QLatin1Char(' '));
-    const QStringList lst = dir->entries();
-    for (const QString &entryName : lst) {
-        const KArchiveEntry *entry = dir->entry(entryName);
-        if (entry) {
-            if (entry->isDirectory()) {
-                const auto *dirEntry = static_cast<const KArchiveDirectory *>(entry);
-                QTreeWidgetItem *newTopItem = addItem(parent, dirEntry->name(), QString());
-                QFont font(newTopItem->font(0));
-                font.setBold(true);
-                mLogFile += space + dirEntry->name() + QLatin1Char('\n');
-                newTopItem->setFont(0, font);
-                addSubItems(topLevelPath, newTopItem, entry, indent, (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) + dirEntry->name());
-            } else if (entry->isFile()) {
-                const auto *file = static_cast<const KArchiveFile *>(entry);
-                const QString fileFullPath = topLevelPath + (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) + file->name();
-                //qDebug() << " fileFullPath " <<fileFullPath;
-                addItem(parent, file->name(), fileFullPath);
-                mLogFile += space + file->name() + QLatin1Char('\n');
-            }
-        }
+  const auto dir = static_cast<const KArchiveDirectory *>(entry);
+  ++indent;
+  const QString space = QString(indent * 2, QLatin1Char(' '));
+  const QStringList lst = dir->entries();
+  for (const QString &entryName : lst) {
+    const KArchiveEntry *entry = dir->entry(entryName);
+    if (entry) {
+      if (entry->isDirectory()) {
+        const auto dirEntry = static_cast<const KArchiveDirectory *>(entry);
+        QTreeWidgetItem *newTopItem =
+            addItem(parent, dirEntry->name(), QString());
+        QFont font(newTopItem->font(0));
+        font.setBold(true);
+        mLogFile += space + dirEntry->name() + QLatin1Char('\n');
+        newTopItem->setFont(0, font);
+        addSubItems(
+            topLevelPath, newTopItem, entry, indent,
+            (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) +
+                dirEntry->name());
+      } else if (entry->isFile()) {
+        const auto file = static_cast<const KArchiveFile *>(entry);
+        const QString fileFullPath =
+            topLevelPath +
+            (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) +
+            file->name();
+        // qDebug() << " fileFullPath " <<fileFullPath;
+        addItem(parent, file->name(), fileFullPath);
+        mLogFile += space + file->name() + QLatin1Char('\n');
+      }
     }
+  }
 }
 
 QTreeWidgetItem *ShowArchiveStructureDialog::addItem(QTreeWidgetItem *parent, const QString &name, const QString &fillFullPath)
 {
-    auto *item = new QTreeWidgetItem(parent);
-    item->setText(0, name);
-    item->setData(0, FullPath, fillFullPath);
-    return item;
+  auto item = new QTreeWidgetItem(parent);
+  item->setText(0, name);
+  item->setData(0, FullPath, fillFullPath);
+  return item;
 }
 
 QTreeWidgetItem *ShowArchiveStructureDialog::addTopItem(const QString &name)
 {
-    auto *item = new QTreeWidgetItem;
-    QFont font = item->font(0);
-    font.setBold(true);
-    item->setFont(0, font);
-    item->setText(0, name);
-    mTreeWidget->addTopLevelItem(item);
-    return item;
+  auto item = new QTreeWidgetItem;
+  QFont font = item->font(0);
+  font.setBold(true);
+  item->setFont(0, font);
+  item->setText(0, name);
+  mTreeWidget->addTopLevelItem(item);
+  return item;
 }
 
 void ShowArchiveStructureDialog::writeConfig()
